@@ -6,11 +6,19 @@
 -module(flex_offline).
 
 -compile({nowarn_unused_function,
-	  [{dec_int, 3}, {dec_int, 1}, {dec_enum, 2},
-	   {dec_enum_int, 2}, {dec_enum_int, 4}, {enc_int, 1},
-	   {enc_enum, 1}, {enc_enum_int, 1}, {not_empty, 1},
-	   {dec_bool, 1}, {enc_bool, 1}, {dec_ip, 1},
-	   {enc_ip, 1}]}).
+          [{dec_int, 3},
+           {dec_int, 1},
+           {dec_enum, 2},
+           {dec_enum_int, 2},
+           {dec_enum_int, 4},
+           {enc_int, 1},
+           {enc_enum, 1},
+           {enc_enum_int, 1},
+           {not_empty, 1},
+           {dec_bool, 1},
+           {enc_bool, 1},
+           {dec_ip, 1},
+           {enc_ip, 1}]}).
 
 -compile(nowarn_unused_vars).
 
@@ -18,50 +26,55 @@
 
 -export([encode/1, encode/2, encode/3]).
 
--export([decode/1, decode/2, decode/3, format_error/1,
-	 io_format_error/1]).
+-export([decode/1,
+         decode/2,
+         decode/3,
+         format_error/1,
+         io_format_error/1]).
 
 -include("xmpp_codec.hrl").
 
 -include("flex_offline.hrl").
 
--export_type([property/0, result/0, form/0,
-	      error_reason/0]).
+-export_type([property/0,
+              result/0,
+              form/0,
+              error_reason/0]).
 
 -define(T(S), <<S>>).
 
 -spec format_error(error_reason()) -> binary().
 
 -spec io_format_error(error_reason()) -> {binary(),
-					  [binary()]}.
+                                          [binary()]}.
 
 -spec decode([xdata_field()]) -> result().
 
 -spec decode([xdata_field()],
-	     [binary(), ...]) -> result().
+             [binary(), ...]) -> result().
 
 -spec decode([xdata_field()], [binary(), ...],
-	     [binary()]) -> result().
+             [binary()]) -> result().
 
 -spec decode([xdata_field()], [binary(), ...],
-	     [binary()], result()) -> result().
+             [binary()], result()) -> result().
 
 -spec do_decode([xdata_field()], binary(), [binary()],
-		result()) -> result().
+                result()) -> result().
 
 -spec encode(form()) -> [xdata_field()].
 
 -spec encode(form(), binary()) -> [xdata_field()].
 
 -spec encode(form(), binary(),
-	     [number_of_messages]) -> [xdata_field()].
+             [number_of_messages]) -> [xdata_field()].
 
 dec_int(Val) -> dec_int(Val, infinity, infinity).
 
 dec_int(Val, Min, Max) ->
     case erlang:binary_to_integer(Val) of
-      Int when Int =< Max, Min == infinity -> Int;
-      Int when Int =< Max, Int >= Min -> Int
+        Int when Int =< Max, Min == infinity -> Int;
+        Int when Int =< Max, Int >= Min -> Int
     end.
 
 enc_int(Int) -> integer_to_binary(Int).
@@ -69,7 +82,7 @@ enc_int(Int) -> integer_to_binary(Int).
 dec_enum(Val, Enums) ->
     AtomVal = erlang:binary_to_existing_atom(Val, utf8),
     case lists:member(AtomVal, Enums) of
-      true -> AtomVal
+        true -> AtomVal
     end.
 
 enc_enum(Atom) -> erlang:atom_to_binary(Atom, utf8).
@@ -79,7 +92,7 @@ dec_enum_int(Val, Enums) ->
 
 dec_enum_int(Val, Enums, Min, Max) ->
     try dec_int(Val, Min, Max) catch
-      _:_ -> dec_enum(Val, Enums)
+        _:_ -> dec_enum(Val, Enums)
     end.
 
 enc_enum_int(Int) when is_integer(Int) -> enc_int(Int);
@@ -100,8 +113,10 @@ dec_ip(Val) ->
     Addr.
 
 enc_ip({0, 0, 0, 0, 0, 65535, A, B}) ->
-    enc_ip({(A bsr 8) band 255, A band 255,
-	    (B bsr 8) band 255, B band 255});
+    enc_ip({(A bsr 8) band 255,
+            A band 255,
+            (B bsr 8) band 255,
+            B band 255});
 enc_ip(Addr) -> list_to_binary(inet_parse:ntoa(Addr)).
 
 format_error({form_type_mismatch, Type}) ->
@@ -143,8 +158,10 @@ io_format_error({missing_required_var, Var, Type}) ->
      [Var, Type]}.
 
 decode(Fs) ->
-    decode(Fs, [<<"http://jabber.org/protocol/offline">>],
-	   [], []).
+    decode(Fs,
+           [<<"http://jabber.org/protocol/offline">>],
+           [],
+           []).
 
 decode(Fs, XMLNSList) -> decode(Fs, XMLNSList, [], []).
 
@@ -152,16 +169,17 @@ decode(Fs, XMLNSList, Required) ->
     decode(Fs, XMLNSList, Required, []).
 
 decode(Fs, [_ | _] = XMLNSList, Required, Acc) ->
-    case lists:keyfind(<<"FORM_TYPE">>, #xdata_field.var,
-		       Fs)
-	of
-      false -> do_decode(Fs, hd(XMLNSList), Required, Acc);
-      #xdata_field{values = [XMLNS]} ->
-	  case lists:member(XMLNS, XMLNSList) of
-	    true -> do_decode(Fs, XMLNS, Required, Acc);
-	    false ->
-		erlang:error({?MODULE, {form_type_mismatch, XMLNS}})
-	  end
+    case lists:keyfind(<<"FORM_TYPE">>,
+                       #xdata_field.var,
+                       Fs)
+        of
+        false -> do_decode(Fs, hd(XMLNSList), Required, Acc);
+        #xdata_field{values = [XMLNS]} ->
+            case lists:member(XMLNS, XMLNSList) of
+                true -> do_decode(Fs, XMLNS, Required, Acc);
+                false ->
+                    erlang:error({?MODULE, {form_type_mismatch, XMLNS}})
+            end
     end.
 
 encode(Cfg) -> encode(Cfg, <<"en">>, []).
@@ -170,70 +188,74 @@ encode(Cfg, Lang) -> encode(Cfg, Lang, []).
 
 encode(List, Lang, Required) ->
     Fs = [case Opt of
-	    {number_of_messages, Val} ->
-		[encode_number_of_messages(Val, Lang,
-					   lists:member(number_of_messages,
-							Required))];
-	    #xdata_field{} -> [Opt]
-	  end
-	  || Opt <- List],
+              {number_of_messages, Val} ->
+                  [encode_number_of_messages(Val,
+                                             Lang,
+                                             lists:member(number_of_messages,
+                                                          Required))];
+              #xdata_field{} -> [Opt]
+          end
+          || Opt <- List],
     FormType = #xdata_field{var = <<"FORM_TYPE">>,
-			    type = hidden,
-			    values =
-				[<<"http://jabber.org/protocol/offline">>]},
+                            type = hidden,
+                            values =
+                                [<<"http://jabber.org/protocol/offline">>]},
     [FormType | lists:flatten(Fs)].
 
 do_decode([#xdata_field{var = <<"number_of_messages">>,
-			values = [Value]}
-	   | Fs],
-	  XMLNS, Required, Acc) ->
+                        values = [Value]}
+           | Fs],
+          XMLNS, Required, Acc) ->
     try dec_int(Value, 0, infinity) of
-      Result ->
-	  do_decode(Fs, XMLNS,
-		    lists:delete(<<"number_of_messages">>, Required),
-		    [{number_of_messages, Result} | Acc])
+        Result ->
+            do_decode(Fs,
+                      XMLNS,
+                      lists:delete(<<"number_of_messages">>, Required),
+                      [{number_of_messages, Result} | Acc])
     catch
-      _:_ ->
-	  erlang:error({?MODULE,
-			{bad_var_value, <<"number_of_messages">>, XMLNS}})
+        _:_ ->
+            erlang:error({?MODULE,
+                          {bad_var_value, <<"number_of_messages">>, XMLNS}})
     end;
 do_decode([#xdata_field{var = <<"number_of_messages">>,
-			values = []} =
-	       F
-	   | Fs],
-	  XMLNS, Required, Acc) ->
+                        values = []} =
+               F
+           | Fs],
+          XMLNS, Required, Acc) ->
     do_decode([F#xdata_field{var = <<"number_of_messages">>,
-			     values = [<<>>]}
-	       | Fs],
-	      XMLNS, Required, Acc);
+                             values = [<<>>]}
+               | Fs],
+              XMLNS,
+              Required,
+              Acc);
 do_decode([#xdata_field{var = <<"number_of_messages">>}
-	   | _],
-	  XMLNS, _, _) ->
+           | _],
+          XMLNS, _, _) ->
     erlang:error({?MODULE,
-		  {too_many_values, <<"number_of_messages">>, XMLNS}});
+                  {too_many_values, <<"number_of_messages">>, XMLNS}});
 do_decode([#xdata_field{var = Var} | Fs], XMLNS,
-	  Required, Acc) ->
+          Required, Acc) ->
     if Var /= <<"FORM_TYPE">> ->
-	   erlang:error({?MODULE, {unknown_var, Var, XMLNS}});
+           erlang:error({?MODULE, {unknown_var, Var, XMLNS}});
        true -> do_decode(Fs, XMLNS, Required, Acc)
     end;
 do_decode([], XMLNS, [Var | _], _) ->
     erlang:error({?MODULE,
-		  {missing_required_var, Var, XMLNS}});
+                  {missing_required_var, Var, XMLNS}});
 do_decode([], _, [], Acc) -> Acc.
 
 -spec encode_number_of_messages(non_neg_integer() |
-				undefined,
-				binary(), boolean()) -> xdata_field().
+                                undefined,
+                                binary(), boolean()) -> xdata_field().
 
 encode_number_of_messages(Value, Lang, IsRequired) ->
     Values = case Value of
-	       undefined -> [];
-	       Value -> [enc_int(Value)]
-	     end,
+                 undefined -> [];
+                 Value -> [enc_int(Value)]
+             end,
     Opts = [],
     #xdata_field{var = <<"number_of_messages">>,
-		 values = Values, required = IsRequired,
-		 type = 'text-single', options = Opts, desc = <<>>,
-		 label =
-		     xmpp_tr:tr(Lang, ?T("Number of Offline Messages"))}.
+                 values = Values, required = IsRequired,
+                 type = 'text-single', options = Opts, desc = <<>>,
+                 label =
+                     xmpp_tr:tr(Lang, ?T("Number of Offline Messages"))}.
