@@ -1,7 +1,7 @@
 %%%-------------------------------------------------------------------
 %%% @author Magnus Henoch <henoch@dtek.chalmers.se>
 %%%
-%%% Copyright (C) 2002-2023 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2024 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -24,7 +24,7 @@
 
 -record(state, {server = <<"">> :: binary()}).
 
-mech_new(_Mech, _Socket, Host, _GetPassword, _CheckPassword, _CheckPasswordDigest) ->
+mech_new(_Mech, _CB, _Mechs, _UAId, Host, _Callbacks) ->
     #state{server = Host}.
 
 mech_step(#state{}, _ClientIn) ->
