@@ -1,6 +1,6 @@
 %%%-------------------------------------------------------------------
 %%%
-%%% Copyright (C) 2002-2023 ProcessOne, SARL. All Rights Reserved.
+%%% Copyright (C) 2002-2024 ProcessOne, SARL. All Rights Reserved.
 %%%
 %%% Licensed under the Apache License, Version 2.0 (the "License");
 %%% you may not use this file except in compliance with the License.
@@ -45,8 +45,13 @@
 	 pp/1,
 	 sockname/1,
 	 peername/1,
-	 send_ws_ping/1, get_negotiated_cipher/1, get_tls_last_message/2,
-	 release/1]).
+	 send_ws_ping/1,
+	 get_negotiated_cipher/1,
+	 get_tls_last_message/2,
+	 release/1,
+	 get_tls_cb_exporter/1,
+	 get_tls_cert_hash/1,
+	 finish_tls_handshake/1]).
 
 -include("xmpp.hrl").
 -include_lib("public_key/include/public_key.hrl").
@@ -68,7 +73,8 @@
 		       max_stanza_size   :: timeout(),
 		       xml_stream :: undefined | fxml_stream:xml_stream_state(),
 		       shaper = none :: none | p1_shaper:state(),
-		       sock_peer_name = none :: none | {endpoint(), endpoint()}}).
+		       sock_peer_name = none :: none | {endpoint(), endpoint()},
+		       tls_certfile = none :: none | binary()}).
 
 -type socket_state() :: #socket_state{}.
 
@@ -168,11 +174,11 @@ starttls(#socket_state{sockmod = gen_tcp,
     case fast_tls:tcp_to_tls(Socket, TLSOpts) of
 	{ok, TLSSocket} ->
 	    SocketData1 = SocketData#socket_state{socket = TLSSocket,
-						  sockmod = fast_tls},
+						  sockmod = fast_tls,
+						  tls_certfile = proplists:get_value(certfile, TLSOpts, none)},
 	    SocketData2 = reset_stream(SocketData1),
 	    case fast_tls:recv_data(TLSSocket, <<>>) of
-		{ok, TLSData} ->
-		    parse(SocketData2, TLSData);
+		{ok, Data} -> parse(SocketData2, Data);
 		{error, _} = Err ->
 		    Err
 	    end;
@@ -182,6 +188,21 @@ starttls(#socket_state{sockmod = gen_tcp,
 starttls(_, _) ->
     erlang:error(badarg).
 
+-spec finish_tls_handshake(socket_state()) ->
+		      {ok, socket_state()} |
+		      {error, inet:posix() | atom() | binary()}.
+ finish_tls_handshake(#socket_state{sockmod = fast_tls,
+		       socket = Socket} = SocketData) ->
+    fast_tls:setopts(Socket, [{active, false}]),
+    case fast_tls:finish_handshake(Socket, 5000) of
+	ok ->
+	    {ok, SocketData};
+	{error, _} = Err ->
+	    Err
+    end;
+finish_tls_handshake(SocketData) ->
+    {ok, SocketData}.
+
 compress(SocketData) -> compress(SocketData, undefined).
 
 compress(#socket_state{sockmod = SockMod,
@@ -347,6 +368,36 @@ get_peer_certificate(#socket_state{sockmod = SockMod,
 	false -> error
     end.
 
+-spec get_tls_cert_hash(socket_state()) -> {ok, binary()} | error.
+get_tls_cert_hash(#socket_state{tls_certfile = none}) ->
+    error;
+get_tls_cert_hash(#socket_state{tls_certfile = Path}) ->
+    case file:read_file(Path) of
+	{ok, Content} ->
+	    try lists:keyfind('Certificate', 1, public_key:pem_decode(Content)) of
+		{'Certificate', Cert, not_encrypted} ->
+		    try public_key:pkix_decode_cert(Cert, otp) of
+			#'OTPCertificate'{signatureAlgorithm = #'SignatureAlgorithm'{algorithm = Algo}} ->
+			    Hash = case public_key:pkix_sign_types(Algo) of
+				{sha, _} -> sha256;
+				{md5, _} -> sha256;
+				{Hash2, _} -> Hash2
+			    end,
+			    {ok, crypto:hash(Hash, Cert)};
+			_ ->
+			    error
+		    catch _:_ ->
+			error
+		    end;
+		_ ->
+		    error
+	    catch _:_ ->
+		error
+	    end;
+	_ ->
+	    error
+    end.
+
 -spec get_negotiated_cipher(socket_state()) -> {ok, binary()} | error.
 get_negotiated_cipher(#socket_state{sockmod = SockMod,
 				    socket = Socket}) ->
@@ -363,6 +414,14 @@ get_tls_last_message(#socket_state{sockmod = SockMod,
 	false -> {error, unavailable}
     end.
 
+-spec get_tls_cb_exporter(socket_state()) -> {ok, binary()} | {error, term()}.
+get_tls_cb_exporter(#socket_state{sockmod = SockMod,
+				  socket = Socket}) ->
+    case erlang:function_exported(SockMod, get_tls_cb_exporter, 1) of
+	true -> SockMod:get_tls_cb_exporter(Socket);
+	false -> {error, unavailable}
+    end.
+
 get_verify_result(SocketData) ->
     fast_tls:get_verify_result(SocketData#socket_state.socket).
 
